pub struct UndeclaredParameters<'a> { /* private fields */ }Expand description
Provides access to undeclared parameters in a ParameterServer
This struct is returned by Node::use_undeclared_parameters() and allows
for dynamic retrieval of parameter values by name without explicit declaration.
Implementations
Sourceimpl<'a> UndeclaredParameters<'a>
impl<'a> UndeclaredParameters<'a>
pub fn new(server: &'a mut ParameterServer) -> Self
Sourcepub fn get_bool(&self, name: &str) -> Option<bool>
pub fn get_bool(&self, name: &str) -> Option<bool>
Try to get the value of an undeclared boolean parameter
Sourcepub fn get_integer(&self, name: &str) -> Option<i64>
pub fn get_integer(&self, name: &str) -> Option<i64>
Try to get the value of an undeclared integer parameter
Sourcepub fn get_double(&self, name: &str) -> Option<f64>
pub fn get_double(&self, name: &str) -> Option<f64>
Try to get the value of an undeclared double parameter
Sourcepub fn get_string(&self, name: &str) -> Option<&str>
pub fn get_string(&self, name: &str) -> Option<&str>
Try to get the value of an undeclared string parameter