ParameterValue

Enum ParameterValue 

pub enum ParameterValue {
    NotSet,
    Bool(bool),
    Integer(i64),
    Double(f64),
    String(String<MAX_STRING_VALUE_LEN>),
    ByteArray(Vec<u8, MAX_BYTE_ARRAY_LEN>),
    BoolArray(Vec<bool, MAX_ARRAY_LEN>),
    IntegerArray(Vec<i64, MAX_ARRAY_LEN>),
    DoubleArray(Vec<f64, MAX_ARRAY_LEN>),
    StringArray(Vec<String<MAX_STRING_VALUE_LEN>, MAX_ARRAY_LEN>),
}
Parameter value container

Holds a parameter value of any supported type. Note: This enum is intentionally large to support all parameter types without heap allocation in embedded systems.

Variants



NotSet

Value not set



Bool(bool)

Boolean value



Integer(i64)

64-bit signed integer value



Double(f64)

64-bit floating point value



String(String<MAX_STRING_VALUE_LEN>)

String value



ByteArray(Vec<u8, MAX_BYTE_ARRAY_LEN>)

Byte array value



BoolArray(Vec<bool, MAX_ARRAY_LEN>)

Boolean array value



IntegerArray(Vec<i64, MAX_ARRAY_LEN>)

Integer array value



DoubleArray(Vec<f64, MAX_ARRAY_LEN>)

Double array value



StringArray(Vec<String<MAX_STRING_VALUE_LEN>, MAX_ARRAY_LEN>)

String array value (array of fixed-size strings)

Implementations

Source

impl ParameterValue

pub fn param_type(&self) -> ParameterType

Get the parameter type for this value

pub fn is_set(&self) -> bool

Check if the value is set

pub fn as_bool(&self) -> Option<bool>

Try to get the value as a bool

pub fn as_integer(&self) -> Option<i64>

Try to get the value as an integer

pub fn as_double(&self) -> Option<f64>

Try to get the value as a double

pub fn as_string(&self) -> Option<&str>

Try to get the value as a string slice

pub fn as_byte_array(&self) -> Option<&[u8]>

Try to get the value as a byte array slice

pub fn as_bool_array(&self) -> Option<&[bool]>

Try to get the value as a bool array slice

pub fn as_integer_array(&self) -> Option<&[i64]>

Try to get the value as an integer array slice

pub fn as_double_array(&self) -> Option<&[f64]>

Try to get the value as a double array slice

pub fn from_bool(value: bool) -> Self

Create a bool value

pub fn from_integer(value: i64) -> Self

Create an integer value

pub fn from_double(value: f64) -> Self

Create a double value

pub fn from_string(value: &str) -> Option<Self>

Create a string value from a str slice